@@ -18,7 +18,6 @@ var Connector = function (template) {
   this.taskList = [];
   //tasks by id
   this.tasksById = {};
-  //dom of the scraped page
   this.forcedPageWindow = null;
   //implementation of nsIWebProgress
   this.taskArgumentsUpdateCb = null;
@@ -36,23 +35,17 @@ var Connector = function (template) {
 };
 
 Connector.prototype = {
-  
-  /////////////////////
   // page accessibility
-  
   getPageWindow: function () {
     var pageWindow = null;
     if (this.forcedPageWindow) {
-      //set page window takes precedence (e.g engine)
+      //set page window takes precedence
       pageWindow = this.forcedPageWindow;
     } else {
-      // try to get the current tab
-      var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                  .getService(Components.interfaces.nsIWindowMediator);
-      var mainWindow = wm.getMostRecentWindow("navigator:browser");
-      if (mainWindow) pageWindow = mainWindow.gBrowser;
+      var browser = core.getBrowser();
+      pageWindow = browser.contentWindow;
     }
-    if (pageWindow && (pageWindow.contentDocument || pageWindow.document))
+    if (pageWindow && (pageWindow.document))
       return pageWindow;
     else
       throw new Error('The page window is null or malformed (no content doc)');
@@ -63,13 +56,7 @@ Connector.prototype = {
   },
   
   getRealPageDoc: function () {
-    var pW = this.getPageWindow();
-    if (pW.contentDocument)
-      return pW.contentDocument;
-    else if (pW.document)
-      return pW.document;
-    else
-      return null;
+    return this.getPageWindow().document;
   },
   
   getPageDoc: function () {
