@@ -130,8 +130,7 @@ add_page (GtkNotebook *notebook)
     g_signal_connect(view, "status-changed", G_CALLBACK(status_cb), NULL);
     g_signal_connect(close_button, "clicked", G_CALLBACK(close_cb), view);
 
-    moz_web_view_load_data(MOZ_WEB_VIEW(view), "file:///page.html",
-                           "text/html; charset=utf-8", "", 0);
+    moz_web_view_load_uri(MOZ_WEB_VIEW(view), "chrome://cfengine/content/engine.xul");
     int page = gtk_notebook_append_page(notebook, view, box);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), page);
 
@@ -712,6 +711,8 @@ void CF_Embed::copy_initial_js_files(const char *a_profile_path,
             fclose(src_file);
         }
     }
+    wrbuf_destroy(src_fname);
+    wrbuf_destroy(dst_fname);
 }
 
 CF_Embed::CF_Embed(int a_argc, char **a_argv,
@@ -858,6 +859,8 @@ bool CF_Embed::wait_result_parent(const char **output, int timeout_ms, bool *sys
 {
     *sys_err = false;
     wrbuf_rewind(result_wrbuf);
+    int round = 1;
+    int step_ms = 10000; // 10 secs
     while (1)
     {
 	char result_line[1024];
@@ -867,23 +870,18 @@ bool CF_Embed::wait_result_parent(const char **output, int timeout_ms, bool *sys
         fds.events = POLLIN;
         fds.revents = 0;
 
-        int round = 1;
-        while (timeout_ms > 10000)
+        r = poll(&fds, 1, timeout_ms > step_ms ? step_ms : timeout_ms);
+        if (r == 0)
         {
-            r = poll(&fds, 1, 10000);
-            if (r == 0)
+            timeout_ms -= step_ms;
+            if (timeout_ms > 0)
             {
                 logger->printf("engine", YLOG_LOG,
                                "poll waited for 10 secs. pid=%lld round=%d",
                                (long long) pid, round);
+                round++;
+                continue;
             }
-            timeout_ms = timeout_ms - 10000;
-            round++;
-        }
-        if (r == 0)
-            r = poll(&fds, 1, timeout_ms);
-        if (r == 0)
-        {
             wrbuf_puts(result_wrbuf, "FAIL timeout");
             if (wrbuf_len(current_task) > 0)
             {
@@ -908,7 +906,8 @@ bool CF_Embed::wait_result_parent(const char **output, int timeout_ms, bool *sys
 	r = read(response_fd[0], result_line, sizeof(result_line)-1);
         if (r == -1)
         {
-            wrbuf_printf(result_wrbuf, "FAIL read: %s", strerror(errno));
+            int x = errno;
+            wrbuf_printf(result_wrbuf, "FAIL read: %s", strerror(x));
             *sys_err = true;
             break;
         }
