@@ -53,19 +53,11 @@ ConnectorWrap::ConnectorWrap(const char *modulePath, CF_Logger *log_int) :
     init(modulePath);
 }
 
-bool ConnectorWrap::setBrowserWindow(nsIDOMWindow *win)
+void ConnectorWrap::setBrowser(nsIWebBrowser *browser)
 {
-    if (!m_c)
-        return false;
     assert(m_c);
-    assert(win);
-    nsresult rv = m_c->SetBrowserWindow(win);
-    if (NS_FAILED(rv))
-    {
-        m_logger->printf("engine", YLOG_WARN, "NS_FAILED findBrowserWindow");
-	return false;
-    }
-    return true;
+    assert(browser);
+    m_c->SetBrowser(browser);
 }
 
 bool ConnectorWrap::loadConf(const char *filePath, const char *sessionJSON, char **errormessage)
