@@ -64,7 +64,7 @@ public:
     bool loadConf(const char *filePath, const char *sessionJSON, char **errormessage);
     bool saveConf(const char *filePath, char **errormessage);
     bool runScript(const char *filePath, char **errormessage);
-    bool setBrowserWindow(nsIDOMWindow *win);
+    void setBrowser(nsIWebBrowser *browser);
     void runTask(const char *taskName, bool optional,
                  const char *jsonStrInput,
 		 void *vp, resultfunc_t *resultfunc);
