@@ -173,6 +173,7 @@ namespace metaproxy_1 {
             std::string http_prefix;
 
             bool enable_z3950;
+            bool close_down;
 
             CF_Factory *cf_factory;
 
@@ -180,6 +181,7 @@ namespace metaproxy_1 {
             int m_connector_next_id;
 
             boost::condition m_cond_session_ready;
+            boost::condition m_cond_expire_ready;
             boost::mutex m_mutex; // protects Rep (m_connectors, id)
             boost::thread_group m_thrds;
         public:
@@ -534,10 +536,17 @@ yf::CF::Rep::Rep()
     max_age = 5;
     enable_z3950 = false;
     m_connector_next_id = 1;
+    close_down = false;
 }
 
 yf::CF::Rep::~Rep()
 {
+    {
+        boost::mutex::scoped_lock lock(m_mutex);
+        close_down = true;
+        m_cond_expire_ready.notify_all();
+    }
+    m_thrds.join_all();
     delete cf_factory;
 }
 
@@ -564,21 +573,21 @@ void yf::CF::Rep::expire(void)
 {
     while (true)
     {
+
         boost::xtime xt;
         boost::xtime_get(&xt,
-#if BOOST_VERSION >= 105000 
+#if BOOST_VERSION >= 105000
                 boost::TIME_UTC_
 #else
                 boost::TIME_UTC
 #endif
                   );
-
         xt.sec += 60;
-        boost::thread::sleep(xt);
-
         {
             boost::mutex::scoped_lock lock(m_mutex);
-
+            m_cond_expire_ready.timed_wait(lock, xt);
+            if (close_down)
+                break;
             std::map<int,WSessionPtr>::iterator map_it;
             map_it = m_connectors.begin();
             while (map_it != m_connectors.end())
@@ -1225,9 +1234,12 @@ Z_APDU *yf::CF::Rep::search_z3950(Z_APDU *req, CF::ZSession *zsession,
         NMEM nmem = ((ODR) odr)->mem;
         struct sort_elem *sort_list = 0;
         type7_sort(sr->query->u.type_1, nmem, &sort_list);
+        Z_FacetList *facet_list =
+            yaz_oi_get_facetlist(&sr->additionalSearchInfo);
 
         if (!rpn_to_json.parse_full(sr->query->u.type_1,
-                                    zsession->subdatabase, sort_list))
+                                    zsession->subdatabase, sort_list,
+                                    facet_list))
         {
             // Should succeed for al reasonable queries. If not, we can
             // declare the whole search a failure.
@@ -1325,6 +1337,7 @@ Z_APDU *yf::CF::Rep::search_z3950(Z_APDU *req, CF::ZSession *zsession,
         estimated_hit_count = true;
     }
 
+    Z_FacetList *facet_list = json_to_facet(res, odr);
     json_remove_node(res);
 
     if (zsession->hits == 0)
@@ -1396,6 +1409,28 @@ Z_APDU *yf::CF::Rep::search_z3950(Z_APDU *req, CF::ZSession *zsession,
     *resp->numberOfRecordsReturned = number_returned;
     *resp->nextResultSetPosition = next_position;
 
+    if (facet_list)
+    {
+        Z_OtherInformation *oi = (Z_OtherInformation *)
+            odr_malloc(odr, sizeof(*oi));
+        Z_OtherInformationUnit *oiu = (Z_OtherInformationUnit *)
+            odr_malloc(odr, sizeof(*oiu));
+        oi->num_elements = 1;
+        oi->list = (Z_OtherInformationUnit **)
+            odr_malloc(odr, oi->num_elements * sizeof(*oi->list));
+        oiu->category = 0;
+        oiu->which = Z_OtherInfo_externallyDefinedInfo;
+        oiu->information.externallyDefinedInfo = (Z_External *)
+            odr_malloc(odr, sizeof(*oiu->information.externallyDefinedInfo));
+        oiu->information.externallyDefinedInfo->direct_reference =
+            odr_oiddup(odr, yaz_oid_userinfo_facet_1);
+        oiu->information.externallyDefinedInfo->descriptor = 0;
+        oiu->information.externallyDefinedInfo->indirect_reference = 0;
+        oiu->information.externallyDefinedInfo->which = Z_External_userFacets;
+        oiu->information.externallyDefinedInfo->u.facetList = facet_list;
+        oi->list[0] = oiu;
+        resp->additionalSearchInfo = oi;
+    }
     return apdu_res;
 }
 
