@@ -6,7 +6,7 @@
 : ${DEBUG=1}
 log_dir=logs
 
-export CF_DISPLAY_LOCK=/tmp/cf-xvfb
+export CF_DISPLAY_LOCK=/tmp/cf-xvfb-$(logname)
 case `uname` in 
    Linux ) ;;
        * ) export CF_APP_PATH=`pwd` ;;
